Object.defineProperty(exports, "__esModule", { value: true });
const validation_methods_1 = require("./validation_methods");
/**
 * バリデーション情報を管理する
 */
class ActiveHashValidation {
    /** コンストラクタ */
    constructor() {
        /** バリデートで検出されたエラー */
        this.errors = [];
        this.validate = this.validate.bind(this);
        this.errorMessages = this.errorMessages.bind(this);
    }
    /**
     * モデルをバリデートする
     * @param model モデル
     * @param validations バリデーションを記述する関数
     */
    validate(model, validations) {
        const validationMethods = new validation_methods_1.ValidationMethods(model, this);
        validationMethods.validates("id", "presence", true);
        validationMethods.validates("id", "uniqueness", true);
        validations(validationMethods);
    }
    /** バリデートで検出されたエラーメッセージ */
    errorMessages() {
        return this.errors.map((error) => `テーブル[${error.model.name}]のレコードID=${error.ids} カラム[${error.column}]において ${error.message}`);
    }
}
exports.ActiveHashValidation = ActiveHashValidation;
/** バリデーションのインスタンス */
exports.activeHashValidation = new ActiveHashValidation();
/** モデルをバリデートする */
exports.validate = exports.activeHashValidation.validate;
//# sourceMappingURL=active_hash_validation.js.map